package org.eco.als.domain.bo;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.eco.als.domain.MaintenanceTask;
import org.eco.common.orm.core.domain.BaseEntity;

import java.util.Date;

/**
 * 维修任务业务对象 als_maintenance_task_t
 *
 * @author wgk
 * @date 2024-07-24
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = MaintenanceTask.class, reverseConvertGenerate = false)
public class MaintenanceTaskBo extends BaseEntity {
    /**
     * 编号
     */
    private Long id;

    /**
     * 架次号
     */
    @NotNull(message = "架次号不能为空")
    private Long sortieNo;

    /**
     * 机号Id
     */
    @NotNull(message = "机号不能为空")
    private String aircraftId;

    /**
     * 所属系统
     */
    @NotBlank(message = "所属系统不能为空")
    private String systemName;

    /**
     * 单位
     */
    @NotBlank(message = "单位不能为空")
    private String unitName;

    /**
     * 处理人
     */
    @NotBlank(message = "处理人不能为空")
    private String operator;

    /**
     * 故障部件
     */
    @NotBlank(message = "故障部件不能为空")
    private String faultPart;

    /**
     * 维修建议
     */
    @NotBlank(message = "维修建议不能为空")
    private String proposal;

    /**
     * 维修时间
     */
    @NotNull(message = "维修时间不能为空")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date handlerDate;

    /**
     * 状态（1正常）
     */
    private String status;


}
