package org.eco.als.domain.vo;

import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import com.eco.common.mapper.annotation.FieldMapper;
import com.eco.common.mapper.constant.MapperConstant;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.eco.als.domain.MaintenanceTask;
import org.eco.common.excel.annotation.ExcelDictFormat;
import org.eco.common.excel.convert.ExcelDictConvert;
import org.eco.common.orm.core.domain.BaseEntity;

import java.io.Serial;
import java.io.Serializable;
import java.util.Date;

/**
 * 维修任务视图对象 als_maintenance_task_t
 *
 * @author wgk
 * @date 2024-07-24
 */
@Data
@ExcelIgnoreUnannotated
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = MaintenanceTask.class)
public class MaintenanceTaskVo extends BaseEntity implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * 编号
     */
    @ExcelProperty(value = "编号")
    private Long id;

    /**
     * 架次号
     */
    @ExcelProperty(value = "架次号")
    private Long sortieNo;

    /**
     * 机号Id
     */
    private String aircraftId;

    /**
     * 机号
     */
    @ExcelProperty(value = "机号")
    @FieldMapper(type = MapperConstant.AIRCRAFT_ID_TO_NO, mapper = "aircraftId")
    private String aircraftNo;

    /**
     * 所属系统
     */
    @ExcelProperty(value = "所属系统")
    private String systemName;

    /**
     * 单位
     */
    @ExcelProperty(value = "单位")
    private String unitName;

    /**
     * 处理人
     */
    @ExcelProperty(value = "处理人")
    private String operator;

    /**
     * 故障部件
     */
    @ExcelProperty(value = "故障部件")
    private String faultPart;

    /**
     * 维修建议
     */
    @ExcelProperty(value = "维修建议")
    private String proposal;

    /**
     * 维修时间
     */
    @ExcelProperty(value = "维修时间")
    private Date handlerDate;

    /**
     * 状态（1正常）
     */
    @ExcelProperty(value = "状态", converter = ExcelDictConvert.class)
    @ExcelDictFormat(dictType = "common_type")
    private String status;

    /**
     * 删除标识（1删除 0未删除）
     */
    private Integer delFlag;


    /**
     * 创建人名称
     */
    @FieldMapper(type = MapperConstant.USER_ID_TO_NAME, mapper = "createBy")
    private String createByName;

    /**
     * 创建人名称
     */
    @FieldMapper(type = MapperConstant.USER_ID_TO_NAME, mapper = "updateBy")
    private String updateByName;

}
