package org.eco.als.listener;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import com.alibaba.excel.context.AnalysisContext;
import com.alibaba.excel.event.AnalysisEventListener;
import org.eco.common.core.exception.BusinessException;
import org.eco.common.core.utils.SpringUtils;
import org.eco.common.core.utils.ValidatorUtils;
import org.eco.common.excel.core.ExcelListener;
import org.eco.common.excel.core.ExcelResult;
import org.eco.common.excel.entity.ExcelResultRes;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.bo.FaultSetpsBo;
import org.eco.als.domain.vo.FaultSetpsImportVo;
import org.eco.als.domain.vo.FaultSetpsVo;
import org.eco.als.service.IFaultSetpsService;
import lombok.extern.slf4j.Slf4j;

import java.util.List;

/**
 * 故障操作步骤自定义导入
 *
 * @author wgk
 */
@Slf4j
public class FaultSetpsImportListener extends AnalysisEventListener<FaultSetpsImportVo> implements ExcelListener<FaultSetpsImportVo> {
    private final IFaultSetpsService faultSetpsService;

    private final Boolean isUpdateSupport;
    private final LoginUser loginUser;
    private int successNum = 0;
    private int failureNum = 0;
    private final StringBuilder successMsg = new StringBuilder();
    private final StringBuilder failureMsg = new StringBuilder();

    public FaultSetpsImportListener(Boolean isUpdateSupport, LoginUser loginUser) {
        this.faultSetpsService = SpringUtils.getBean(IFaultSetpsService.class);
        this.isUpdateSupport = isUpdateSupport;
        this.loginUser = loginUser;
    }

    @Override
    public void invoke(FaultSetpsImportVo faultSetpsVo, AnalysisContext context) {
        try {

            FaultSetpsBo faultSetpsBo = BeanUtil.toBean(faultSetpsVo, FaultSetpsBo.class);

            //TODO:根据某个字段，查询数据库表中是否存在记录，不存在就新增，存在就更新
            FaultSetpsVo faultSetpsVo1 = null;

            //faultSetpsVo1 = faultSetpsService.selectBySomefield(faultSetpsVo.getSomefield());
            if (ObjectUtil.isNull(faultSetpsVo1)) {
                //不存在就新增
                setBo(faultSetpsBo);
                ValidatorUtils.validate(faultSetpsBo);
                boolean inserted = faultSetpsService.insert(faultSetpsBo);

                if (inserted) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、故障操作步骤 记录导入成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、故障操作步骤 记录导入失败");
                }
            } else if (isUpdateSupport) {
                //存在就更新
                faultSetpsBo.setId(faultSetpsVo1.getId());//主键
                faultSetpsBo.setVersion(faultSetpsVo1.getVersion());
                boolean updated = faultSetpsService.update(faultSetpsBo);
                if (updated) {
                    successNum++;
                    successMsg.append("<br/>").append(successNum).append("、故障操作步骤 记录更新成功");
                } else {
                    failureNum++;
                    failureMsg.append("<br/>").append(failureNum).append("、故障操作步骤 记录更新失败");
                }
            }
        } catch (Exception e) {
            failureNum++;
            String msg = "<br/>" + failureNum + "、故障操作步骤 记录导入失败：";
            failureMsg.append(msg).append(e.getMessage());
            log.error(msg, e);
        }
    }

    private void setBo(FaultSetpsBo faultSetpsBo) {
        faultSetpsBo.setVersion(0);
        faultSetpsBo.setCreateBy(loginUser.getUserId());
        faultSetpsBo.setUpdateBy(loginUser.getUserId());
        faultSetpsBo.setTenantId(loginUser.getTenantId());
    }

    @Override
    public void doAfterAllAnalysed(AnalysisContext context) {
        log.info("解析完成");
    }

    @Override
    public ExcelResult<FaultSetpsImportVo> getExcelResult() {
        return new ExcelResult<>() {

            @Override
            public ExcelResultRes getAnalysis() {
                if (failureNum > 0 && successNum == 0) {
                    failureMsg.insert(0, "很抱歉，导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("0").build();
                } else if (failureNum > 0 && successNum > 0) {
                    failureMsg.insert(0, "很抱歉，部分导入失败！共 " + failureNum + " 条数据没有成功导入，错误如下：");
                    return ExcelResultRes.builder().logInfo(failureMsg.toString()).status("2").build();
                } else {
                    successMsg.insert(0, "恭喜您，数据已全部导入成功！共 " + successNum + " 条，数据如下：");
                    return ExcelResultRes.builder().logInfo(successMsg.toString()).status("1").build();
                }
            }

            @Override
            public List<FaultSetpsImportVo> getList() {
                return null;
            }

            @Override
            public List<String> getErrorList() {
                return null;
            }
        };
    }
}
