package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.FaultConsumable;
import org.eco.als.domain.vo.FaultConsumableVo;
import org.eco.als.domain.bo.FaultConsumableBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 故障所需耗材Service接口
 *
 * @author wgk
 * @date 2024-10-25
 */
public interface IFaultConsumableService extends IBaseService<FaultConsumable> {
    /**
     * 查询故障所需耗材
     *
     * @param id 故障所需耗材主键
     * @return 故障所需耗材
     */
    FaultConsumableVo selectById(Long id);

    /**
     * 查询故障所需耗材列表
     *
     * @param faultConsumableBo 故障所需耗材Bo
     * @return 故障所需耗材集合
     */
    List<FaultConsumableVo> selectList(FaultConsumableBo faultConsumableBo);

    /**
     * 分页查询故障所需耗材列表
     *
     * @param faultConsumableBo 故障所需耗材Bo
     * @return 分页故障所需耗材集合
     */
    PageResult<FaultConsumableVo> selectPage(FaultConsumableBo faultConsumableBo);

    /**
     * 新增故障所需耗材
     *
     * @param faultConsumableBo 故障所需耗材Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultConsumableBo faultConsumableBo);

    /**
     * 新增故障所需耗材，前台提供主键值，一般用于导入的场合
     *
     * @param faultConsumableBo 故障所需耗材Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultConsumableBo faultConsumableBo);

    /**
     * 修改故障所需耗材
     *
     * @param faultConsumableBo 故障所需耗材Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultConsumableBo faultConsumableBo);

    /**
     * 批量删除故障所需耗材
     *
     * @param ids 需要删除的故障所需耗材主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FaultConsumableVo> listVo, String sheetName, LoginUser user);

}
