package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.FaultEquipment;
import org.eco.als.domain.vo.FaultEquipmentVo;
import org.eco.als.domain.bo.FaultEquipmentBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 故障所需设备Service接口
 *
 * @author wgk
 * @date 2024-10-25
 */
public interface IFaultEquipmentService extends IBaseService<FaultEquipment> {
    /**
     * 查询故障所需设备
     *
     * @param id 故障所需设备主键
     * @return 故障所需设备
     */
    FaultEquipmentVo selectById(Long id);

    /**
     * 查询故障所需设备列表
     *
     * @param faultEquipmentBo 故障所需设备Bo
     * @return 故障所需设备集合
     */
    List<FaultEquipmentVo> selectList(FaultEquipmentBo faultEquipmentBo);

    /**
     * 分页查询故障所需设备列表
     *
     * @param faultEquipmentBo 故障所需设备Bo
     * @return 分页故障所需设备集合
     */
    PageResult<FaultEquipmentVo> selectPage(FaultEquipmentBo faultEquipmentBo);

    /**
     * 新增故障所需设备
     *
     * @param faultEquipmentBo 故障所需设备Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultEquipmentBo faultEquipmentBo);

    /**
     * 新增故障所需设备，前台提供主键值，一般用于导入的场合
     *
     * @param faultEquipmentBo 故障所需设备Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultEquipmentBo faultEquipmentBo);

    /**
     * 修改故障所需设备
     *
     * @param faultEquipmentBo 故障所需设备Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultEquipmentBo faultEquipmentBo);

    /**
     * 批量删除故障所需设备
     *
     * @param ids 需要删除的故障所需设备主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FaultEquipmentVo> listVo, String sheetName, LoginUser user);

}
