package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.FaultNotes;
import org.eco.als.domain.vo.FaultNotesVo;
import org.eco.als.domain.bo.FaultNotesBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 故障注意事项Service接口
 *
 * @author wgk
 * @date 2024-10-25
 */
public interface IFaultNotesService extends IBaseService<FaultNotes> {
    /**
     * 查询故障注意事项
     *
     * @param id 故障注意事项主键
     * @return 故障注意事项
     */
    FaultNotesVo selectById(Long id);

    /**
     * 查询故障注意事项列表
     *
     * @param faultNotesBo 故障注意事项Bo
     * @return 故障注意事项集合
     */
    List<FaultNotesVo> selectList(FaultNotesBo faultNotesBo);

    /**
     * 分页查询故障注意事项列表
     *
     * @param faultNotesBo 故障注意事项Bo
     * @return 分页故障注意事项集合
     */
    PageResult<FaultNotesVo> selectPage(FaultNotesBo faultNotesBo);

    /**
     * 新增故障注意事项
     *
     * @param faultNotesBo 故障注意事项Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultNotesBo faultNotesBo);

    /**
     * 新增故障注意事项，前台提供主键值，一般用于导入的场合
     *
     * @param faultNotesBo 故障注意事项Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultNotesBo faultNotesBo);

    /**
     * 修改故障注意事项
     *
     * @param faultNotesBo 故障注意事项Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultNotesBo faultNotesBo);

    /**
     * 批量删除故障注意事项
     *
     * @param ids 需要删除的故障注意事项主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FaultNotesVo> listVo, String sheetName, LoginUser user);

}
