package org.eco.als.service;

import java.util.List;

import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.als.domain.FaultSetps;
import org.eco.als.domain.vo.FaultSetpsVo;
import org.eco.als.domain.bo.FaultSetpsBo;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;
import org.springframework.web.multipart.MultipartFile;
import org.eco.common.core.core.page.PageResult;

/**
 * 故障操作步骤Service接口
 *
 * @author wgk
 * @date 2024-10-25
 */
public interface IFaultSetpsService extends IBaseService<FaultSetps> {
    /**
     * 查询故障操作步骤
     *
     * @param id 故障操作步骤主键
     * @return 故障操作步骤
     */
    FaultSetpsVo selectById(Long id);

    /**
     * 查询故障操作步骤列表
     *
     * @param faultSetpsBo 故障操作步骤Bo
     * @return 故障操作步骤集合
     */
    List<FaultSetpsVo> selectList(FaultSetpsBo faultSetpsBo);

    /**
     * 分页查询故障操作步骤列表
     *
     * @param faultSetpsBo 故障操作步骤Bo
     * @return 分页故障操作步骤集合
     */
    PageResult<FaultSetpsVo> selectPage(FaultSetpsBo faultSetpsBo);

    /**
     * 新增故障操作步骤
     *
     * @param faultSetpsBo 故障操作步骤Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(FaultSetpsBo faultSetpsBo);

    /**
     * 新增故障操作步骤，前台提供主键值，一般用于导入的场合
     *
     * @param faultSetpsBo 故障操作步骤Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(FaultSetpsBo faultSetpsBo);

    /**
     * 修改故障操作步骤
     *
     * @param faultSetpsBo 故障操作步骤Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(FaultSetpsBo faultSetpsBo);

    /**
     * 批量删除故障操作步骤
     *
     * @param ids 需要删除的故障操作步骤主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * 异步导入
     *
     * @param file          导入的文件
     * @param updateSupport 是否覆盖
     * @param user          用户上下文信息
     */
    @Async
    void asyncImportData(MultipartFile file, boolean updateSupport, LoginUser user);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<FaultSetpsVo> listVo, String sheetName, LoginUser user);

}
