package org.eco.als.service;

import org.eco.als.domain.MaintenanceTask;
import org.eco.als.domain.bo.MaintenanceTaskBo;
import org.eco.als.domain.vo.MaintenanceTaskVo;
import org.eco.common.core.core.domain.model.LoginUser;
import org.eco.common.core.core.page.PageResult;
import org.eco.common.orm.core.service.IBaseService;
import org.springframework.scheduling.annotation.Async;

import java.util.List;

/**
 * 维修任务Service接口
 *
 * @author wgk
 * @date 2024-07-24
 */
public interface IMaintenanceTaskService extends IBaseService<MaintenanceTask> {
    /**
     * 查询维修任务
     *
     * @param id 维修任务主键
     * @return 维修任务
     */
    MaintenanceTaskVo selectById(Long id);

    /**
     * 查询维修任务列表
     *
     * @param maintenanceTaskBo 维修任务Bo
     * @return 维修任务集合
     */
    List<MaintenanceTaskVo> selectList(MaintenanceTaskBo maintenanceTaskBo);

    /**
     * 分页查询维修任务列表
     *
     * @param maintenanceTaskBo 维修任务Bo
     * @return 分页维修任务集合
     */
    PageResult<MaintenanceTaskVo> selectPage(MaintenanceTaskBo maintenanceTaskBo);

    /**
     * 新增维修任务
     *
     * @param maintenanceTaskBo 维修任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insert(MaintenanceTaskBo maintenanceTaskBo);

    /**
     * 新增维修任务，前台提供主键值，一般用于导入的场合
     *
     * @param maintenanceTaskBo 维修任务Bo
     * @return 结果:true 操作成功，false 操作失败
     */
    boolean insertWithPk(MaintenanceTaskBo maintenanceTaskBo);

    /**
     * 修改维修任务
     *
     * @param maintenanceTaskBo 维修任务Bo
     * @return 结果:true 更新成功，false 更新失败
     */
    boolean update(MaintenanceTaskBo maintenanceTaskBo);

    /**
     * 批量删除维修任务
     *
     * @param ids 需要删除的维修任务主键集合
     * @return 结果:true 删除成功，false 删除失败
     */
    boolean deleteByIds(Long[] ids);

    /**
     * asyncExport 异步导出
     *
     * @param listVo    数据列表
     * @param sheetName 文件名称
     * @param user      上下文
     */
    @Async
    void asyncExport(List<MaintenanceTaskVo> listVo, String sheetName, LoginUser user);

}
